@@ -40,6 +40,7 @@ def run_in_bash(cmd):
     return cmd
 
 def run_ise(entity_name, input_xls, Sheet, ouput_csv, drop,ise_path, Run_with_gui = False):
+    ise_path = load_file( ise_path  ).strip()
     build_path = "build/"+entity_name+"/"
     intermediate_csv = build_path + entity_name+ ".csv"
     programm_name = entity_name+".exe"
@@ -61,7 +62,7 @@ def run_ise(entity_name, input_xls, Sheet, ouput_csv, drop,ise_path, Run_with_gu
         if  Run_with_gui:
             return
         try_remove_file(build_path + programm_name )
-        cmd = ise_path + " && cd " + build_path + " && " + "fuse -intstyle ise -incremental -lib secureip -o " + programm_name+ " -prj "+ project_name + "  work." + entity_name
+        cmd = "source " + ise_path + " && cd " + build_path + " && " + "fuse -intstyle ise -incremental -lib secureip -o " + programm_name+ " -prj "+ project_name + "  work." + entity_name
         cmd = run_in_bash(cmd)
         vprint(2)("command: " + cmd)
         os.system(cmd)
@@ -71,7 +72,7 @@ def run_ise(entity_name, input_xls, Sheet, ouput_csv, drop,ise_path, Run_with_gu
     
     def run_program():
         make_tcl_file( entity_name , intermediate_csv, build_path+tclbatchfile, do_quit = tcl_do_quit)
-        cmd = ise_path + " cd "+ build_path+ " && ./" + programm_name + " -intstyle ise -tclbatch " +tclbatchfile + cmd_arg_gui
+        cmd = "source " +  ise_path + " cd "+ build_path+ " && ./" + programm_name + " -intstyle ise -tclbatch " +tclbatchfile + cmd_arg_gui
         cmd = run_in_bash(cmd)
         vprint(2)("command: " + cmd)
         os.system(cmd )
